@@ -411,6 +411,9 @@ class _Unmarshaller:
         except KeyError:
             raise ValueError("bad marshal code: %c (%d)" % (c, Ord(c)))
 
+    def r_byte(self):
+        return Ord(self._read(1))
+
     def r_short(self):
         lo = Ord(self._read(1))
         hi = Ord(self._read(1))
@@ -453,6 +456,7 @@ class _Unmarshaller:
 
     def load_none(self):
         return None
+
     dispatch[TYPE_NONE] = load_none
 
     def load_true(self):
@@ -463,6 +467,10 @@ class _Unmarshaller:
         return False
     dispatch[TYPE_FALSE] = load_false
 
+    def load_ascii(self):
+        return self.r_byte()
+    dispatch[TYPE_ASCII] = load_null
+
     def load_stopiter(self):
         return StopIteration
     dispatch[TYPE_STOPITER] = load_stopiter
